/*
 * File: Zypper.h
 * Created: Apr 2008
 * Last modified: Wed 23 Apr 2008
 * Author: Adrian Łubik
 * License: GNU LGPL v3 or newer
 */


#ifndef _ZYPPER_H_
#define _ZYPPER_H_

#include <QDebug>
#include <QString>
#include <QStringList>
#include <QByteArray>
#include <QRegExp>
#include <QProcess>
#include <QThread>

#include "MyProcess.h"
//#include "PackageManager.h"
#include "Rpm.h"
#include "FileManager.h"

struct Repository
{
    int number;
    bool enabled;
    bool refresh;
    QString type;
    QString alias;
    QString name;
};

typedef QList<Repository> Repositories;
typedef QListIterator<Repository> RepositoriesIterator;

class Zypper: public Rpm
{
    Q_OBJECT
public:
    Zypper( QThread *parent = 0 );
    virtual ~Zypper();

    virtual int  installPackages ( const QStringList &pkgs );
    virtual int  addCD ( const QString &mntPoint );
    virtual bool getArePackagesAvailable ( const QStringList &pkgs );

    int  addRepo ( const QString &path, const QString &alias );
    bool enableRepo ( QString alias, bool enable );
    bool enableRepo ( const QString &alias ) { return enableRepo ( alias, true ); }
    bool disableRepo ( const QString &alias ) { return enableRepo ( alias, false ); }

    Repositories getRepos();

private slots:
    void debugProcess ( QByteArray ba );
    void debugZyppRepos ( QByteArray ba );

private:
    QByteArray dbg;
    MyProcess *m_installProcess;
    MyProcess *m_zypperProcess;
    QProcess  *m_addRepoProcess;
    QProcess  *m_modifyRepoProcess;
    QProcess  *m_getAvailableProcess;

    Repositories repos;
    QRegExp      repoRegExp;
    QRegExp      processing;
    QThread     *m_parentThread;
};

#endif
