#include "Table.h"

Table::Table ( QWidget *parent ) : QWidget ( parent )
{
    setMinimumSize ( QSize ( 100, 100 ) );
    setMaximumSize ( QSize ( 300, 300 ) );
    lbl = new QLabel ( this );
    lbl->setGeometry ( 10, 10, 180, 190 );
    op = 0.0;
    timer = new QTimer;
    m_hidden = true;
    m_text = "";
    setVisible ( false, true );
}

void Table::paintEvent ( QPaintEvent * )
{
    QColor bgColor = QColor ( 255, 255, 255 );

    QRectF mainRect ( 0.0, 0.0, 200.0, 200.0 );

    QPainter painter ( this );
    painter.setRenderHint ( QPainter::TextAntialiasing, true );
    painter.setWindow ( 0, 0, 194, 204 );
    painter.setPen ( Qt::NoPen );

    QBrush mainBrush ( bgColor );
    painter.setOpacity ( op );
    painter.setBrush ( mainBrush );
    painter.drawRect ( mainRect );

    painter.setPen ( QColor ( 101, 101, 101 ) );
    QFont font ( "Free Sans", 8, QFont::Bold );
    font.insertSubstitutions("Free Sans", QStringList() << "Nimbus Sans L" << "Luxi Sans" << "Lucida Sans" << "Andale Sans");
    painter.setFont ( font );
    painter.drawText ( QRect ( 7, 10, 176, 184 ), Qt::AlignLeft | Qt::TextWordWrap, m_text );
}

void Table::fadeIn()
{
    if ( !m_hidden )
        return;

    if ( op >= 1.0 )
    {
        timer->stop();
        m_hidden = false;
        disconnect ( timer, SIGNAL ( timeout() ), this, SLOT ( fadeIn() ) );
        emit shown();
    }
    else
        op += 0.1;
    repaint();
}

void Table::fadeOut()
{
    if ( m_hidden )
        return;

    if ( op <= 0.0 )
    {
        timer->stop();
        m_hidden = true;
        disconnect ( timer, SIGNAL ( timeout() ), this, SLOT ( fadeOut() ) );
        emit hidden();
    }
    else
        op -= 0.1;
    repaint();
}

void Table::setVisible ( bool visible, bool instantly )
{
    if ( visible && !instantly )
    {
        op = 0.0;
        connect ( timer, SIGNAL ( timeout() ), this, SLOT ( fadeIn() ) );
        timer->start ( 30 );
    }
    else if ( !visible && !instantly )
    {
        op = 1.0;
        connect ( timer, SIGNAL ( timeout() ), this, SLOT ( fadeOut() ) );
        timer->start ( 30 );
    }
    else if ( visible && instantly )
    {
        op = 1.0;
        repaint();
    }
    else if ( !visible && instantly )
    {
        op = 0.0;
        repaint();
    }
}

void Table::setText ( const QString &t )
{
    if ( m_text == t )
        return;

    if ( !m_hidden )
    {
        hide();
        QEventLoop el;
        connect ( this, SIGNAL ( hidden() ), &el, SLOT ( quit() ) );
        el.exec();
        m_text = t;
        disconnect ( this, SIGNAL ( hidden() ), &el, SLOT ( quit() ) );
        show();
    }
    else
        m_text = t;
};
